@@ -8,18 +8,18 @@ use Math::BigInt::Calc 0.56;
 
 use vars '$VERSION';
 
-$VERSION = '0.24';
+$VERSION = '0.25';
 
 ##############################################################################
 # global constants, flags and accessory
 
 # announce that we are compatible with MBI v1.70 and up
 sub api_version () { 1; }
- 
+
 # use Calc to override the methods that we do not provide in XS
 
 for my $method (qw/
-    str
+    str num
     add sub mul div
     rsft lsft
     mod modpow modinv
@@ -43,7 +43,9 @@ XSLoader::load(__PACKAGE__, $VERSION, Math::BigInt::Calc::_base_len());
 ##############################################################################
 
 1;
+
 __END__
+
 =pod
 
 =head1 NAME
@@ -84,23 +86,42 @@ The following functions are now implemented in FastCalc.xs:
 	_is_odd		_is_even	_is_one		_is_zero
 	_is_two		_is_ten
 	_zero		_one		_two		_ten
-	_acmp		_len		_num
+	_acmp		_len
 	_inc		_dec
 	__strip_zeros	_copy
 
 =head1 LICENSE
- 
+
 This program is free software; you may redistribute it and/or modify it under
-the same terms as Perl itself. 
+the same terms as Perl itself.
 
 =head1 AUTHORS
 
+=over 4
+
+=item *
+
 Original math code by Mark Biggar, rewritten by Tels L<http://bloodgate.com/>
 in late 2000.
+
+=item *
+
 Seperated from BigInt and shaped API with the help of John Peacock.
+
+=item *
+
 Fixed, sped-up and enhanced by Tels http://bloodgate.com 2001-2003.
+
+=item *
+
 Further streamlining (api_version 1 etc.) by Tels 2004-2007.
 
+=item *
+
+Bug-fixing by Peter John Acklam E<lt>pjacklam@online.noE<gt> 2010.
+
+=back
+
 =head1 SEE ALSO
 
 L<Math::BigInt>, L<Math::BigFloat>,
